@@ -2,29 +2,24 @@
 import os
 from dynaconf.utils.parse_conf import parse_conf_data
 
-try:
-    from dotenv import load_dotenv, find_dotenv
-except ImportError:  # pragma: no cover
-    load_dotenv = lambda *args, **kwargs: None  # noqa
-    find_dotenv = lambda: None  # noqa
-
-
 IDENTIFIER = 'env_loader'
 
 
 def load(obj, namespace=None, silent=True, key=None):
-    # load_from_dotenv_if_installed
-    load_dotenv(
-        obj.get('DOTENV_PATH', find_dotenv(usecwd=True)),
-        verbose=obj.get('DOTENV_VERBOSE', False),
-        override=obj.get('DOTENV_OVERRIDE', False)
+    default_namespace = obj.get('BASE_NAMESPACE_FOR_DYNACONF')
+    # load all from default namespace (this never gets cleaned)
+    load_from_env(
+        IDENTIFIER,
+        key,
+        default_namespace,
+        obj,
+        silent
     )
 
-    # load all from default namespace (this never gets cleaned)
-    load_from_env(IDENTIFIER, key, obj.get('DYNACONF_NAMESPACE'), obj, silent)
+    namespace = namespace or obj.current_namespace
 
     # rewrite with different namespace if provided
-    if namespace and namespace != obj.get('DYNACONF_NAMESPACE'):
+    if namespace and namespace != default_namespace:
         identifier = IDENTIFIER + '_' + namespace.lower()
         load_from_env(identifier, key, namespace, obj, silent)
 
@@ -38,6 +33,12 @@ def load_from_env(identifier, key, namespace, obj, silent):
                 '{0}_{1}'.format(NAMESPACE, key)
             )
             if value:
+                obj.logger.debug(
+                    "env_loader:loading by key: %s:%s (%s)",
+                    key,
+                    value,
+                    identifier
+                )
                 obj.set(key, value, loader_identifier=identifier)
         else:
             data = {
@@ -46,6 +47,11 @@ def load_from_env(identifier, key, namespace, obj, silent):
                 in os.environ.items()
                 if key.startswith(NAMESPACE_)
             }
+            obj.logger.debug(
+                "env_loader:loading:%s (%s)",
+                data,
+                identifier
+            )
             obj.update(data, loader_identifier=identifier)
     except Exception as e:  # pragma: no cover
         e.message = (
@@ -59,6 +65,7 @@ def load_from_env(identifier, key, namespace, obj, silent):
 
 def clean(obj, namespace, silent=True):  # noqa
     for identifier, data in obj.loaded_by_loaders.items():
-        if identifier.startswith('env_loader_'):
+        if identifier.startswith('env_loader'):
             for key in data:
+                obj.logger.debug("cleaning: %s (%s)", key, identifier)
                 obj.unset(key)
