@@ -24,13 +24,15 @@ def load(obj, namespace=None, silent=True, key=None):
     :return: None
     """
     redis = StrictRedis(**obj.get('REDIS_FOR_DYNACONF'))
-    namespace = namespace or obj.get('DYNACONF_NAMESPACE')
+    namespace = namespace or obj.current_namespace
     holder = "DYNACONF_%s" % namespace
     try:
         if key:
-            value = parse_conf_data(redis.hget(holder.upper(), key))
+            value = redis.hget(holder.upper(), key)
             if value:
-                obj.set(key, value)
+                parsed_value = parse_conf_data(value)
+                if parsed_value:
+                    obj.set(key, parsed_value)
         else:
             data = {
                 key: parse_conf_data(value)
@@ -39,10 +41,9 @@ def load(obj, namespace=None, silent=True, key=None):
             if data:
                 obj.update(data, loader_identifier=IDENTIFIER)
     except Exception as e:
-        e.message = 'Unable to load config from redis (%s)' % e.message
         if silent:
             if hasattr(obj, 'logger'):
-                obj.logger.error(e.message)
+                obj.logger.error(str(e))
             return False
         raise
 
@@ -60,20 +61,25 @@ def clean(obj, namespace, silent=True):  # noqa
         obj.unset(key)
 
 
-def write(obj, **kwargs):
+def write(obj, data=None, **kwargs):
     """
     Write a value in to loader source
     :param obj: settings object
+    :param data: vars to be stored
     :param kwargs: vars to be stored
     :return:
     """
     client = StrictRedis(**obj.REDIS_FOR_DYNACONF)
-    holder = "DYNACONF_%s" % obj.DYNACONF_NAMESPACE
-    data = {
+    holder = "DYNACONF_%s" % obj.current_namespace
+    data = data or {}
+    data.update(kwargs)
+    if not data:
+        raise AttributeError('Data must be provided')
+    redis_data = {
         key.upper(): unparse_conf_data(value)
-        for key, value in kwargs.items()
+        for key, value in data.items()
     }
-    client.hmset(holder.upper(), data)
+    client.hmset(holder.upper(), redis_data)
     load(obj)
 
 
@@ -85,7 +91,7 @@ def delete(obj, key=None):
     :return: None
     """
     client = StrictRedis(**obj.REDIS_FOR_DYNACONF)
-    holder = "DYNACONF_%s" % obj.DYNACONF_NAMESPACE
+    holder = "DYNACONF_%s" % obj.current_namespace
     if key:
         client.hdel(holder.upper(), key.upper())
         obj.unset(key)
