@@ -1,7 +1,8 @@
 # coding: utf-8
 
-from conf import settings
+from dynaconf import settings
 
 print(settings.MYSQL_HOST)  # noqa
 print(settings.MYSQL_PASSWD)  # noqa
 print(settings.EXAMPLE)  # noqa
+print(settings.WORKS)  # noqa
